import type {
  FC,
  MouseEvent,
} from 'react';
import React, {
  useCallback,
  useMemo,
} from 'react';

import { useWalletModal } from '../hooks';
import type { ButtonProps } from './Button';
import { Button } from './Button';

export const WalletModalButton: FC<ButtonProps> = ({ children, onClick, ...props }) => {
  const { visible, setVisible, trans } = useWalletModal()

  const childrenElement = useMemo(() => {
    if (children) return children
    return trans.connect_wallet
  }, [children, trans])

  const handleClick = useCallback(
    (event: MouseEvent<HTMLButtonElement>) => {
      if (onClick) onClick(event)
      if (!event.defaultPrevented) setVisible(!visible)
    },
    [onClick, setVisible, visible],
  )

  return (
    <Button
      className="wallet-adapter-button-trigger"
      onClick={handleClick}
      {...props}
    >
      {childrenElement}
    </Button>
  )
}
